psychopy_ext.plot.Plot.plot — psychopy_ext 0.5.4 documentation
Author: Jonas Kubilius
Description: A framework for a rapid reproducible design, analysis and plotting of experiments in neuroscience and psychology

# psychopy_ext.plot.Plot.plot

`Plot.` `plot`(agg, kind='bar', subplots=None, subplots_order=None, autoscale=True, title=None, errkind='sem', within=None, xlim=None, ylim=None, xlabel=None, ylabel=None, popmean=0, numb=False, **kwargs)

  The main plotting function.

  Args: | agg (pandas.DataFrame or similar) A structured input, preferably a pandas.DataFrame, but in principle accepts anything that can be converted into it.
  Kwargs: | subplots (None, True, or False; default=None) Whether you want to split data into subplots or not. If True, the top level is treated as a subplot. If None, detects automatically based on agg.columns.names – the first entry to start with subplots. will be used. This is the default output from stats.aggregate and is recommended. kwargs Keyword arguments for plotting
  Returns: | A list of axes of all plots.